@@ -1,22 +1,9 @@
 /*
-    This file is part of kdev-python, the python language plugin for KDevelop
-    Copyright (C) 2012  Sven Brauch <svenbrauch@googlemail.com>
+    SPDX-FileCopyrightText: 2012 Sven Brauch <svenbrauch@googlemail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef PDBDEBUGSESSION_H
 #define PDBDEBUGSESSION_H
 
@@ -37,13 +24,13 @@ using namespace KDevelop;
 namespace Python {
 
 struct PdbCommand;
-    
+struct StartupInfo;
+
 class DebugSession : public KDevelop::IDebugSession
 {
     Q_OBJECT
 public:
-    DebugSession(QStringList program, const QUrl& workingDirectory,
-                 const QString& envProfileName);
+    DebugSession();
     ~DebugSession() override;
 
     IBreakpointController* breakpointController() const override;
@@ -52,8 +39,8 @@ public:
     /**
      * @brief Start the debugger.
      **/
-    void start();
-    
+    void start(const StartupInfo& info);
+
     /**
      * @brief Adds a command to the queue.
      * Commands are processed in the same order they're added.
@@ -133,6 +120,11 @@ public:
      * it'll just kill it.
      **/
     void stopDebugger() override;
+
+    /**
+     * @brief Kill the debugger process synchronously
+     **/
+    void killDebuggerNow() override;
     
     /**
      * @brief Gives the debugger state.
@@ -176,7 +168,7 @@ public:
      **/
     void write(const QByteArray& cmd);
 
-public slots:
+public Q_SLOTS:
     /**
      * @brief Emitted when new data has been received from the debugger process (via stdout)
      **/
@@ -202,7 +194,7 @@ public slots:
     void locationUpdateReady(QByteArray data);
     void debuggerQuit(int);
 
-signals:
+Q_SIGNALS:
     /// Emitted when the debugger becomes ready to process a new command, i.e. shows its prompt
     void debuggerReady();
     /// Emitted when a new command is added to the queue
@@ -216,12 +208,10 @@ private:
     IVariableController* m_variableController;
     IFrameStackModel* m_frameStackModel;
     KProcess* m_debuggerProcess;
-    IDebugSession::DebuggerState m_state;
+    DebuggerState m_state = DebuggerState::NotStartedState;
     QByteArray m_buffer;
-    QStringList m_program;
     QList<PdbCommand*> m_commandQueue;
-    const QUrl& m_workingDirectory;
-    const QString m_envProfileName;
+
 private:
     /// objects to notify next
     QPointer<QObject> m_nextNotifyObject;
@@ -250,6 +240,11 @@ private:
      * @brief Clear the data accumulated in m_buffer.
      **/
     void clearOutputBuffer();
+
+    /**
+     * @brief Clean up and switch to EndedState after stopping/killing the debugger
+     **/
+    void finalizeState();
     
     /// stores whether the data currently received comes from the debugger
     /// or the debuggee.
@@ -315,7 +310,7 @@ public:
         m_type = InvalidType;
     };
     void run(DebugSession* session) override {
-        Q_ASSERT(m_command.endsWith('\n') && "command must end with a newline");
+        Q_ASSERT(m_command.endsWith(QLatin1Char('\n')) && "command must end with a newline");
         qCDebug(KDEV_PYTHON_DEBUGGER) << "running command:" << m_command<< m_notifyMethod;
         session->write(m_command.toUtf8());
     }
